@@ -1,3 +1,6 @@
+#' @include hidden.R
+NULL
+
 #' DBIDriver class
 #'
 #' Base class for all DBMS drivers (e.g., RSQLite, MySQL, PostgreSQL).
@@ -55,10 +58,11 @@ setClass("DBIDriver", contains = c("DBIObject", "VIRTUAL"))
 #' @export
 setGeneric("dbDriver",
   def = function(drvName, ...) standardGeneric("dbDriver"),
-  valueClass = "DBIDriver")
+  valueClass = "DBIDriver"
+)
 
 #' @rdname hidden_aliases
-setMethod("dbDriver", "character",
+setMethod("dbDriver", signature("character"),
   definition = function(drvName, ...) {
     findDriver(drvName)(...)
   }
@@ -67,12 +71,13 @@ setMethod("dbDriver", "character",
 #' @rdname hidden_aliases
 #' @param object Object to display
 #' @export
-setMethod("show", "DBIDriver", function(object) {
+setMethod("show", signature("DBIDriver"), function(object) {
   tryCatch(
     # to protect drivers that fail to implement the required methods (e.g.,
     # RPostgreSQL)
     show_driver(object),
-    error = function(e) NULL)
+    error = function(e) NULL
+  )
   invisible(NULL)
 })
 
@@ -99,11 +104,13 @@ findDriver <- function(drvName) {
   }
 
   # Can't find it:
-  stop("Couldn't find driver ", drvName, ". Looked in:\n",
+  stop(
+    "Couldn't find driver ", drvName, ". Looked in:\n",
     "* global namespace\n",
     "* in package called ", drvName, "\n",
     "* in package called ", pkgName,
-    call. = FALSE)
+    call. = FALSE
+  )
 }
 
 get2 <- function(x, env) {
@@ -133,6 +140,10 @@ setGeneric("dbUnloadDriver",
 #' objects.
 #' The authentication mechanism is left unspecified, so check the
 #' documentation of individual drivers for details.
+#' Use [dbCanConnect()] to check if a connection can be established.
+#'
+#' @template methods
+#' @templateVar method_name dbConnect
 #'
 #' @inherit DBItest::spec_driver_connect return
 #' @inheritSection DBItest::spec_driver_connect Specification
@@ -161,11 +172,54 @@ setGeneric("dbConnect",
   valueClass = "DBIConnection"
 )
 
+#' Check if a connection to a DBMS can be established
+#'
+#' Like [dbConnect()], but only checks validity without actually returning
+#' a connection object.  The default implementation opens a connection
+#' and disconnects on success, but individual backends might implement
+#' a lighter-weight check.
+#'
+#' @template methods
+#' @templateVar method_name dbCanConnect
+#'
+#' @return A scalar logical.  If `FALSE`, the `"reason"` attribute indicates
+#'   a reason for failure.
+#'
+#' @inheritParams dbConnect
+#' @family DBIDriver generics
+#' @export
+#' @examples
+#' # SQLite only needs a path to the database. (Here, ":memory:" is a special
+#' # path that creates an in-memory database.) Other database drivers
+#' # will require more details (like user, password, host, port, etc.)
+#' dbCanConnect(RSQLite::SQLite(), ":memory:")
+setGeneric("dbCanConnect",
+  def = function(drv, ...) standardGeneric("dbCanConnect"),
+  valueClass = "logical"
+)
+
+#' @rdname hidden_aliases
+#' @export
+setMethod("dbCanConnect", signature("DBIDriver"), function(drv, ...) {
+  tryCatch(
+    {
+      con <- dbConnect(drv, ...)
+      dbDisconnect(con)
+      TRUE
+    },
+    error = function(e) {
+      structure(
+        FALSE,
+        reason = conditionMessage(e)
+      )
+    }
+  )
+})
+
 #' List currently open connections
 #'
-#' Drivers that implement only a single connections MUST return a list
-#' containing a single element. If no connection are open, methods MUST
-#' return an empty list.
+#' DEPRECATED, drivers are no longer required to implement this method.
+#' Keep track of the connections you opened if you require a list.
 #'
 #' @param drv A object inheriting from [DBIDriver-class]
 #' @param ... Other arguments passed on to methods.
@@ -196,6 +250,9 @@ setGeneric("dbListConnections",
 #' Notice that many DBMS do not follow IEEE arithmetic, so there are potential
 #' problems with under/overflows and loss of precision.
 #'
+#' @template methods
+#' @templateVar method_name dbDataType
+#'
 #' @inherit DBItest::spec_driver_data_type return
 #' @inheritSection DBItest::spec_driver_data_type Specification
 #' @inheritSection DBItest::spec_result_create_table_with_data_type Specification
@@ -242,6 +299,6 @@ setGeneric("dbDataType",
 
 #' @rdname hidden_aliases
 #' @export
-setMethod("dbDataType", "DBIObject", function(dbObj, obj, ...) {
+setMethod("dbDataType", signature("DBIObject"), function(dbObj, obj, ...) {
   dbiDataType(obj)
 })
