@@ -1,3 +1,6 @@
+#' @include hidden.R
+NULL
+
 #' DBIObject class
 #'
 #' Base class for all other DBI classes (e.g., drivers, connections). This
@@ -74,7 +77,7 @@ setClass("DBIObject", "VIRTUAL")
 #' @return a named list
 #' @export
 setGeneric("dbGetInfo",
-   def = function(dbObj, ...) standardGeneric("dbGetInfo")
+  def = function(dbObj, ...) standardGeneric("dbGetInfo")
 )
 
 #' Is this DBMS object still valid?
@@ -82,6 +85,9 @@ setGeneric("dbGetInfo",
 #' This generic tests whether a database object is still valid (i.e. it hasn't
 #' been disconnected or cleared).
 #'
+#' @template methods
+#' @templateVar method_name dbIsValid
+#'
 #' @inherit DBItest::spec_meta_is_valid return
 #'
 #' @inheritParams dbGetInfo
@@ -105,8 +111,29 @@ setGeneric("dbGetInfo",
 #' dbIsValid(con)
 setGeneric("dbIsValid",
   def = function(dbObj, ...) standardGeneric("dbIsValid"),
+  valueClass = "logical"
+)
+
+#' Is this DBMS object read only?
+#'
+#' This generic tests whether a database object is read only.
+#'
+#' @inheritParams dbGetInfo
+#' @family DBIDriver generics
+#' @family DBIConnection generics
+#' @family DBIResult generics
+#' @export
+#' @examples
+#' dbIsReadOnly(ANSI())
+setGeneric("dbIsReadOnly",
+  def = function(dbObj, ...) standardGeneric("dbIsReadOnly"),
   valueClass = "logical")
 
+#' @rdname hidden_aliases
+setMethod("dbIsReadOnly", "DBIObject", function(dbObj, ...) {
+  FALSE
+})
+
 setGeneric("summary")
 setMethod("summary", "DBIObject", function(object, ...) {
   info <- dbGetInfo(dbObj = object, ...)
